Changelog
=========

Version 0.1.2 (2022-11-28)
--------------------------

* Explicit handling of invalid values (drop, keep, raise).
* Separation of initialization and calculation.
* Benchmarking vs RunStats.

Version 0.1.1 (2022-11-01)
--------------------------

Version 0.1.0 (2022-10-30)
--------------------------

* Initial release
